@@ -1,6 +1,5 @@
 # simple and general slots called by gui.py
 
-import os
 from PySide2.QtWidgets import QLineEdit, QFileDialog, QMessageBox
 
 def openFileDialog(fileType, lineEdit):
@@ -19,7 +18,7 @@ def openFileDialog(fileType, lineEdit):
         fileName, _ = QFileDialog.getOpenFileName(
             None,
             f'Choose {fileType} file',
-            os.getcwd(),
+            '',
             f'All Files (*)'
         )
         lineEdit.setText(fileName)
@@ -42,7 +41,7 @@ def openFilesDialog(fileType, listWidget):
         fileNames, _ = QFileDialog.getOpenFileNames(
             None,
             f'Choose {fileType} files',
-            os.getcwd(),
+            '',
             f'All Files (*)'
         )
         listWidget.addItems(fileNames)
